tuplettools.change_fixed_duration_tuplets_in_expr_to_tuplets
============================================================

.. autofunction:: abjad.tools.tuplettools.change_fixed_duration_tuplets_in_expr_to_tuplets.change_fixed_duration_tuplets_in_expr_to_tuplets
   :noindex:
